@@ -1480,7 +1480,7 @@ void fpm_tray_icon() {
     gtk_widget_show (GTK_WIDGET(lookup_widget (gui->main_window , "hide_to_tray")));
 }
 
-gboolean fpm_hide_main_window() {
+gboolean fpm_hide_main_window(gpointer user_data) {
     gtk_widget_hide(gui->main_window);
     return FALSE;
 }
